""" Known instances of eltern-portal.org """

# pylint: disable=too-many-lines

from .school import School

SCHOOLS = [
    School(
        school="abendrsau",
        name="Abendrealschule Augsburg",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="abstgym",
        name="Anton-Bruckner-Gymnasium Straubing",
        postcode="94315",
        city="Straubing",
    ),
    School(
        school="aegymuc",
        name="Albert-Einstein-Gymnasium München",
        postcode="81545",
        city="München",
    ),
    School(
        school="agbersau",
        name="Agnes-Bernauer-Schule - Realschule für Mädchen",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="akgkitz",
        name="Armin-Knab-Gymnasium Kitzingen",
        postcode="97318",
        city="Kitzingen",
    ),
    School(
        school="alblaugy",
        name="Albertus-Gymnasium Lauingen",
        postcode="89415",
        city="Lauingen (Donau)",
    ),
    School(
        school="alkemgym",
        name="Allgäu-Gymnasium Kempten",
        postcode="87435",
        city="Kempten (Allgäu)",
    ),
    School(
        school="amgydie",
        name="Ammersee-Gymnasium Dießen",
        postcode="86911",
        city="Dießen am Ammersee",
    ),
    School(
        school="amorgym",
        name="Karl-Ernst-Gymnasium Amorbach",
        postcode="63916",
        city="Amorbach",
    ),
    School(
        school="anfragym",
        name="Anne-Frank-Gymnasium Erding",
        postcode="85435",
        city="Erding",
    ),
    School(
        school="ansfobo",
        name="Berufliche Oberschule Ansbach",
        postcode="91522",
        city="Ansbach",
    ),
    School(
        school="apgying",
        name="Apian-Gymnasium Ingolstadt",
        postcode="85051",
        city="Ingolstadt",
    ),
    School(
        school="asamgymuc",
        name="Asam-Gymnasium München",
        postcode="81541",
        city="München",
    ),
    School(
        school="astipagym",
        name="Adalbert-Stifter-Gymnasium Passau",
        postcode="94032",
        city="Passau",
    ),
    School(
        school="aufreugy",
        name="Auersperg-Gymnasium",
        postcode="94034",
        city="Passau",
    ),
    School(
        school="augystan",
        name="Gymnasium bei St. Anna",
        postcode="86159",
        city="Augsburg",
    ),
    School(
        school="augysteph",
        name="Gymnasium bei St. Stephan Augsburg",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="austafach",
        name="Staatsinstitut für die Ausbildung von Fachlehrern",
    ),
    School(
        school="avegybu",
        name="Aventinus-Gymnasium Burghausen",
        postcode="84489",
        city="Burghausen",
    ),
    School(
        school="avhgym",
        name="Alexander-von-Humboldt-Gymnasium Schweinfurt",
        postcode="97424",
        city="Schweinfurt",
    ),
    School(
        school="bagyeich",
        name="Eichendorff-Gymnasium Bamberg",
        postcode="96050",
        city="Bamberg",
    ),
    School(
        school="baiblgy",
        name="Gymnasium Bad Aibling",
        postcode="83043",
        city="Bad Aibling",
    ),
    School(
        school="baykola",
        name="Bayernkolleg Augsburg",
        postcode="86169",
        city="Augsburg",
    ),
    School(
        school="bbgymuc",
        name="Städtisches Bertolt-Brecht-Gymnasium München",
        postcode="81243",
        city="München",
    ),
    School(
        school="bngmh",
        name="Balthasar-Neumann-Gymnasium Marktheidenfeld",
        postcode="97828",
        city="Marktheidenfeld",
    ),
    School(
        school="bskoegy",
        name="Benedikt-Stattler-Gymnasium Bad Kötzting",
        postcode="93444",
        city="Bad Kötzting",
    ),
    School(
        school="bszhof2ws",
        name="Staatliche Wirtschaftsschule Hof",
        postcode="95028",
        city="Hof",
    ),
    School(
        school="bugymal",
        name="Burkhart-Gymnasium Mallersdorf-Pfaffenberg",
        postcode="84066",
        city="Mallersdorf-Pfaffenberg",
    ),
    School(
        school="bukugym",
        name="Gymnasium Burgkunstadt",
        postcode="96224",
        city="Burgkunstadt",
    ),
    School(
        school="casigym",
        name="Gymnasium Casimirianum Coburg",
        postcode="96450",
        city="Coburg",
    ),
    School(
        school="cavigy",
        name="Caspar-Vischer-Gymnasium Kulmbach",
        postcode="95326",
        city="Kulmbach",
    ),
    School(
        school="cjtgylau",
        name="Christoph-Jacob-Treu-Gymnasium Lauf",
        postcode="91207",
        city="Lauf an der Pegnitz",
    ),
    School(
        school="comgydeg",
        name="Comenius-Gymnasium Deggendorf",
    ),
    School(
        school="cpgygil",
        name="Christoph Probst Gymnasium Gilching",
        postcode="82205",
        city="Gilching",
    ),
    School(
        school="csgying",
        name="Christoph-Scheiner-Gymnasium",
        postcode="85049",
        city="Ingolstadt",
    ),
    School(
        school="dantemuc",
        name="Dante-Gymnasium München",
        postcode="81371",
        city="München",
    ),
    School(
        school="degfobo",
        name="Aloys-Fischer-Schule Deggendorf",
        postcode="94469",
        city="Deggendorf",
    ),
    School(
        school="degyaich",
        name="Deutschherren-Gymnasium Aichach",
        postcode="86551",
        city="Aichach",
    ),
    School(
        school="deigs",
        name="Grundschule Deisenhofen",
        postcode="82041",
        city="Oberhaching",
    ),
    School(
        school="deroko",
        name="Robert-Koch-Gymnasium Deggendorf",
        postcode="94469",
        city="Deggendorf",
    ),
    School(
        school="dilgyjms",
        name="Johann-Michael-Sailer-Gymnasium",
        postcode="89407",
        city="Dillingen a.d.Donau",
    ),
    School(
        school="dingogym",
        name="Gymnasium Dingolfing",
        postcode="84130",
        city="Dingolfing",
    ),
    School(
        school="domfreigy",
        name="Dom-Gymnasium Freising",
        postcode="85354",
        city="Freising",
    ),
    School(
        school="domgyreg",
        name="Gymnasium der Regensburger Domspatzen",
        postcode="93055",
        city="Regensburg",
    ),
    School(
        school="donaugym",
        name="Gymnasium Donauwörth",
        postcode="86609",
        city="Donauwörth",
    ),
    School(
        school="dorfgym",
        name="Gymnasium Dorfen",
        postcode="84405",
        city="Dorfen",
    ),
    School(
        school="dzglan",
        name="Dominikus-Zimmermann-Gymnasium Landsberg am Lech",
        postcode="86899",
        city="Landsberg am Lech",
    ),
    School(
        school="ebgymuc",
        name="Städtisches Elsa-Brändström-Gymnasium München",
        postcode="81241",
        city="München",
    ),
    School(
        school="eckegym",
        name="Gymnasium Eckental",
        postcode="90542",
        city="Eckental",
    ),
    School(
        school="ehrforgy",
        name="Ehrenbürg-Gymnasium Forchheim",
        postcode="91301",
        city="Forchheim",
    ),
    School(
        school="emagyha",
        name="Ernst-Mach-Gymnasium Haar",
        postcode="85540",
        city="Haar",
    ),
    School(
        school="engyerl",
        name="Emmy-Noether-Gymnasium Erlangen",
        postcode="91058",
        city="Erlangen",
    ),
    School(
        school="ergogym",
        name="Gymnasium Ergolding",
        postcode="84030",
        city="Ergolding",
    ),
    School(
        school="ergosfz",
        name="Sonderpädagogisches Förderzentrum Landshut-Land",
        postcode="84030",
        city="Ergolding",
    ),
    School(
        school="esgymuc",
        name="Erzbischöfliches Edith-Stein-Gymnasium",
        postcode="81667",
        city="München",
    ),
    School(
        school="etahgybam",
        name="E.T.A. Hoffmann-Gymnasium Bamberg",
        postcode="96049",
        city="Bamberg",
    ),
    School(
        school="evbspar",
        name="Emil-von-Behring-Gymnasium Spardorf",
    ),
    School(
        school="fagyneu",
        name="Friedrich-Alexander-Gymnasium",
        postcode="91413",
        city="Neustadt an der Aisch",
    ),
    School(
        school="ffbgrg",
        name="Graf-Rasso-Gymnasium",
        postcode="82256",
        city="Fürstenfeldbruck",
    ),
    School(
        school="finrogym",
        name="Sebastian-Finsterwalder-Gymnasium Rosenheim",
        postcode="83022",
        city="Rosenheim",
    ),
    School(
        school="fkgwue",
        name="Friedrich-Koenig-Gymnasium",
        postcode="97082",
        city="Würzburg",
    ),
    School(
        school="flgybam",
        name="Franz-Ludwig-Gymnasium Bamberg",
    ),
    School(
        school="framagym",
        name="Franz-Marc-Gymnasium",
        postcode="85570",
        city="Markt Schwaben",
    ),
    School(
        school="freicamgy",
        name="Camerloher-Gymnasium Freising",
        postcode="85354",
        city="Freising",
    ),
    School(
        school="freigymuc",
        name="Gymnasium Freiham",
        postcode="81248",
        city="München",
    ),
    School(
        school="fridgyerl",
        name="Gymnasium Fridericianum",
        postcode="19053",
        city="Schwerin",
    ),
    School(
        school="friebos",
        name="Berufliche Oberschule Friedberg",
        postcode="86316",
        city="Friedberg",
    ),
    School(
        school="friedgym",
        name="Gymnasium Friedberg",
        postcode="86316",
        city="Friedberg",
    ),
    School(
        school="fuerimuc",
        name="Gymnasium Fürstenried",
        postcode="81475",
        city="München",
    ),
    School(
        school="gagymain",
        name="Gabelsberger-Gymnasium Mainburg",
        postcode="84048",
        city="Mainburg",
    ),
    School(
        school="gargym",
        name="Gymnasium Gars",
        postcode="83536",
    ),
    School(
        school="gesaholl",
        name="Staatliche Gesamtschule Hollfeld",
    ),
    School(
        school="gisgymuc",
        name="Gisela-Gymnasium München",
        postcode="80801",
        city="München",
    ),
    School(
        school="gk",
        name="Gymnasium Kirchheim",
        postcode="85551",
        city="Kirchheim bei München",
    ),
    School(
        school="gmgbay",
        name="Graf-Münster-Gymnasium Bayreuth",
        postcode="95444",
        city="Bayreuth",
    ),
    School(
        school="gmshaag",
        name="Grund- und Mittelschule Haag i. OB",
        postcode="83527",
        city="Haag in Oberbayern",
    ),
    School(
        school="gmslaufen",
        name="Ruperti Grund- und Mittelschule Laufen",
        postcode="83410",
        city="Laufen",
    ),
    School(
        school="gn",
        name="Gymnasium Neubiberg",
        postcode="85579",
        city="Neubiberg",
    ),
    School(
        school="gnadgym",
        name="Gnadenthal-Gymnasium Ingolstadt der Diözese Eichstätt",
    ),
    School(
        school="go",
        name="Gymnasium Ottobrunn",
        postcode="85521",
        city="Ottobrunn",
    ),
    School(
        school="grafgym",
        name="Max-Mannheimer-Gymnasium Grafing",
        postcode="85567",
        city="Grafing bei München",
    ),
    School(
        school="groebegy",
        name="Gymnasium Gröbenzell",
        postcode="82194",
    ),
    School(
        school="gruewagym",
        name="Gymnasium Grünwald",
        postcode="82031",
        city="Grünwald",
    ),
    School(
        school="gsgstu",
        name="Geschwister-Scholl-Gymnasium Stuttgart-Sillenbuch",
        postcode="70619",
        city="Stuttgart",
    ),
    School(
        school="gsuhg",
        name="Grundschule am Sportpark",
    ),
    School(
        school="gykisee",
        name="Gymnasium Kirchseeon",
        postcode="85614",
    ),
    School(
        school="gymmod",
        name="Gymnasium Marktoberdorf",
        postcode="87616",
        city="Marktoberdorf",
    ),
    School(
        school="gympan",
        name="Gymnasium Pfarrkirchen",
        postcode="84347",
        city="Pfarrkirchen",
    ),
    School(
        school="gymzwie",
        name="Gymnasium Zwiesel",
        postcode="94227",
        city="Zwiesel",
    ),
    School(
        school="gypenz",
        name="Gymnasium Penzberg",
        postcode="82377",
        city="Penzberg",
    ),
    School(
        school="halegyla",
        name="Hans-Leinberger-Gymnasium Landshut",
        postcode="84034",
        city="Landshut",
    ),
    School(
        school="hamfrogy",
        name="Frobenius-Gymnasium Hammelburg",
        postcode="97762",
        city="Hammelburg",
    ),
    School(
        school="hcgla",
        name="Hans-Carossa-Gymnasium",
        postcode="14089",
        city="Berlin",
    ),
    School(
        school="hehegymuc",
        name="Städt. Heinrich-Heine-Gymnasium",
    ),
    School(
        school="helagyfue",
        name="Helene-Lange-Gymnasium Fürth",
        postcode="90762",
        city="Fürth",
    ),
    School(
        school="heraugy",
        name="Gymnasium Herzogenaurach",
        postcode="91074",
        city="Herzogenaurach",
    ),
    School(
        school="hertrogym",
        name="Hertzhaimer-Gymnasium Trostberg",
        postcode="83308",
        city="Trostberg",
    ),
    School(
        school="hilgykem",
        name="Hildegardis-Gymnasium Kempten",
        postcode="87439",
        city="Kempten (Allgäu)",
    ),
    School(
        school="hoesiegym",
        name="Gymnasium Höhenkirchen-Siegertsbrunn",
        postcode="85635",
        city="Höhenkirchen-Siegertsbrunn",
    ),
    School(
        school="holgyau",
        name="Holbein-Gymnasium",
        postcode="86150",
        city="Augsburg",
    ),
    School(
        school="holkigym",
        name="Gymnasium Holzkirchen",
        postcode="83607",
        city="Holzkirchen",
    ),
    School(
        school="hoschgym",
        name="Gymnasium Hohenschwangau",
        postcode="87645",
    ),
    School(
        school="hsgyerl",
        name="Hermann-Staudinger-Gymnasium Erlenbach a. Main",
        postcode="63906",
        city="Erlenbach am Main",
    ),
    School(
        school="hsgyfue",
        name="Heinrich-Schliemann-Gymnasium",
        postcode="90762",
        city="Fürth",
    ),
    School(
        school="hsgyhoe",
        name="Hanns-Seidel-Gymnasium Hösbach",
        postcode="63768",
        city="Hösbach",
    ),
    School(
        school="hugyvat",
        name="Humboldt-Gymnasium-Vaterstetten",
        postcode="85598",
        city="Vaterstetten",
    ),
    School(
        school="hvbrsau",
        name="Heinrich-von-Buz Realschule Augsburg",
        postcode="86154",
        city="Augsburg",
    ),
    School(
        school="ickigym",
        name="Rainer-Maria-Rilke-Gymnasium Icking",
        postcode="82057",
    ),
    School(
        school="igtadah",
        name="Ignaz-Taschner-Gymnasium",
        postcode="85221",
        city="Dachau",
    ),
    School(
        school="iguerogym",
        name="Ignaz-Günther-Gymnasium Rosenheim",
        postcode="83022",
        city="Rosenheim",
    ),
    School(
        school="illvoegy",
        name="Illertal-Gymnasium Vöhringen",
        postcode="89269",
        city="Vöhringen",
    ),
    School(
        school="indomagy",
        name="Gymnasium Markt Indersdorf",
        postcode="85229",
        city="Markt Indersdorf",
    ),
    School(
        school="irmrs",
        name="Erzbischöfliche St.-Irmengard-Realschule",
    ),
    School(
        school="jafugyau",
        name="Jakob-Fugger-Gymnasium Augsburg",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="jcrgyhof",
        name="Johann-Christian-Reinhart-Gymnasium Hof",
        postcode="95030",
        city="Hof",
    ),
    School(
        school="joguwa",
        name="Johannes-Gutenberg-Gymnasium Waldkirchen",
        postcode="94065",
        city="Waldkirchen",
    ),
    School(
        school="joheitrau",
        name="Johannes-Heidenhain-Gymnasium Traunreut",
        postcode="83301",
        city="Traunreut",
    ),
    School(
        school="johofrei",
        name="Josef-Hofmiller-Gymnasium Freising",
        postcode="85354",
        city="Freising",
    ),
    School(
        school="jonegyro",
        name="Johannes-Nepomuk-Gymnasium",
        postcode="93352",
    ),
    School(
        school="jpgyho",
        name="Jean-Paul-Gymnasium Hof",
        postcode="95028",
        city="Hof",
    ),
    School(
        school="jsgbk",
        name="Jack-Steinberger-Gymnasium Bad Kissingen",
        postcode="97688",
        city="Bad Kissingen",
    ),
    School(
        school="jsgkarl",
        name="Johann-Schöner-Gymnasium Karlstadt",
        postcode="97753",
        city="Karlstadt",
    ),
    School(
        school="julineu",
        name="Justus-von-Liebig-Gymnasium",
        postcode="86356",
        city="Neusäß",
    ),
    School(
        school="jvfgcham",
        name="Joseph-von-Fraunhofer-Gymnasium Cham",
        postcode="93413",
        city="Cham",
    ),
    School(
        school="kagerd",
        name="Korbinian-Aigner-Gymnasium Erding",
        postcode="85435",
        city="Erding",
    ),
    School(
        school="karlsgymuc",
        name="Karlsgymnasium München",
        postcode="81243",
        city="München",
    ),
    School(
        school="karogyro",
        name="Karolinen-Gymnasium Rosenheim",
        postcode="83022",
        city="Rosenheim",
    ),
    School(
        school="kepgywei",
        name="Kepler-Gymnasium Weiden",
        postcode="92637",
        city="Weiden in der Oberpfalz",
    ),
    School(
        school="kgbarei",
        name="Karlsgymnasium Bad Reichenhall",
        postcode="83435",
        city="Bad Reichenhall",
    ),
    School(
        school="khgygrae",
        name="Kurt-Huber-Gymnasium Gräfelfing",
        postcode="82166",
        city="Gräfelfing",
    ),
    School(
        school="klengymuc",
        name="Klenze-Gymnasium München",
        postcode="81371",
        city="München",
    ),
    School(
        school="koebrugy",
        name="Gymnasium Königsbrunn",
        postcode="86343",
        city="Königsbrunn",
    ),
    School(
        school="krogya",
        name="Kronberg-Gymnasium Aschaffenburg",
        postcode="63739",
        city="Aschaffenburg",
    ),
    School(
        school="ksigym",
        name="Kolleg der Schulbrüder Illertissen",
        postcode="89257",
        city="Illertissen",
    ),
    School(
        school="kumagybu",
        name="Kurfürst-Maximilian-Gymnasium Burghausen",
        postcode="84489",
        city="Burghausen",
    ),
    School(
        school="kvc",
        name="Karl-von-Closen-Gymnasium Eggenfelden",
    ),
    School(
        school="lalegygra",
        name="Landgraf-Leuchtenberg-Gymnasium Grafenau",
        postcode="94481",
        city="Grafenau",
    ),
    School(
        school="landau",
        name="Gymnasium Landau a.d. Isar",
        postcode="94405",
        city="Landau an der Isar",
    ),
    School(
        school="leigyalt",
        name="Leibniz-Gymnasium Altdorf",
        postcode="90518",
        city="Altdorf bei Nürnberg",
    ),
    School(
        school="lessgynu",
        name="Lessing-Gymnasium Neu-Ulm",
        postcode="89231",
        city="Neu-Ulm",
    ),
    School(
        school="liefraurs",
        name="Liebfrauenschule Diessen",
        postcode="86911",
        city="Dießen am Ammersee",
    ),
    School(
        school="lifegymuc",
        name="Städtisches Lion-Feuchtwanger-Gymnasium München",
        postcode="80807",
        city="München",
    ),
    School(
        school="lindgym",
        name="Gymnasium Lindenberg",
        postcode="88161",
        city="Lindenberg im Allgäu",
    ),
    School(
        school="lmguhag",
        name="Lise-Meitner-Gymnasium Unterhaching",
        postcode="82008",
        city="Unterhaching",
    ),
    School(
        school="losgymuc",
        name="Städtisches Louise-Schroeder-Gymnasium München",
        postcode="80999",
        city="München",
    ),
    School(
        school="lshmar",
        name="Gymnasium Landschulheim Marquartstein",
        postcode="83250",
    ),
    School(
        school="lsising",
        name="Landschulheim Schloss Ising am Chiemsee",
        postcode="83339",
    ),
    School(
        school="lskempf",
        name="Landschulheim Kempfenhausen",
        postcode="82335",
    ),
    School(
        school="ltgyprie",
        name="Ludwig-Thoma-Gymnasium",
        postcode="83209",
        city="Prien am Chiemsee",
    ),
    School(
        school="ludgymuc",
        name="Ludwigsgymnasium München",
        postcode="81377",
        city="München",
    ),
    School(
        school="ludgystra",
        name="Ludwigsgymnasium Straubing",
        postcode="94315",
        city="Straubing",
    ),
    School(
        school="luigywas",
        name="Luitpold-Gymnasium Wasserburg am Inn",
        postcode="83512",
        city="Wasserburg am Inn",
    ),
    School(
        school="luise",
        name="Städtisches Luisengymnasium",
        postcode="80333",
        city="München",
    ),
    School(
        school="lupomuc",
        name="Luitpold-Gymnasium München",
        postcode="80538",
        city="München",
    ),
    School(
        school="lwgschwab",
        name="Leonhard-Wagner-Gymnasium Schwabmünchen",
    ),
    School(
        school="mabogym",
        name="Max-Born-Gymnasium",
        postcode="82110",
        city="Germering",
    ),
    School(
        school="marbugym",
        name="Marianum Buxheim Gymnasium des Schulwerks der Diözese Augsburg",
        postcode="87740",
        city="Buxheim",
    ),
    School(
        school="marktgym",
        name="Gymnasium Marktbreit",
        postcode="97340",
        city="Marktbreit",
    ),
    School(
        school="mathemuc",
        name="Maria-Theresia-Gymnasium",
        postcode="81541",
        city="München",
    ),
    School(
        school="maxgymuc",
        name="Maximiliansgymnasium München",
        postcode="80803",
        city="München",
    ),
    School(
        school="mgf",
        name="Maristengymnasium Fürstenzell",
        postcode="94081",
    ),
    School(
        school="mggwue",
        name="Matthias-Grünewald-Gymnasium Würzburg",
        postcode="97074",
        city="Würzburg",
    ),
    School(
        school="michamuc",
        name="Michaeli-Gymnasium München",
        postcode="81671",
        city="München",
    ),
    School(
        school="mjsmuc",
        name="Staatliches Gymnasium Max-Josef-Stift München",
        postcode="81677",
        city="München",
    ),
    School(
        school="mmgyvil",
        name="Maximilian-von-Montgelas-Gymnasium",
        postcode="84137",
        city="Vilsbiburg",
    ),
    School(
        school="mogymuc",
        name="Staatliches Gymnasium München-Moosach",
        postcode="80993",
        city="München",
    ),
    School(
        school="moosgym",
        name="Karl-Ritter-von-Frisch-Gymnasium",
        postcode="85368",
        city="Moosburg",
    ),
    School(
        school="mpgymel",
        name="Martin-Pollich-Gymnasium Mellrichstadt",
        postcode="97638",
        city="Mellrichstadt",
    ),
    School(
        school="mswas",
        name="Mittelschule Wasserburg am Inn",
        postcode="83512",
        city="Wasserburg am Inn",
    ),
    School(
        school="mtgyau",
        name="Maria-Theresia-Gymnasium Augsburg",
        postcode="86150",
        city="Augsburg",
    ),
    School(
        school="mtgyerl",
        name="Städtisches Marie-Therese-Gymnasium Erlangen",
        postcode="91054",
        city="Erlangen",
    ),
    School(
        school="muebegy",
        name="Gymnasium Münchberg",
        postcode="95213",
        city="Münchberg",
    ),
    School(
        school="muenomuc",
        name="Gymnasium München-Nord",
        postcode="80937",
        city="München",
    ),
    School(
        school="mwgyal",
        name="Maria-Ward-Gymnasium Altötting",
        postcode="84503",
        city="Altötting",
    ),
    School(
        school="mwgyau",
        name="Maria-Ward-Gymnasium Augsburg",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="mwgygz",
        name="Maria-Ward-Gymnasium Günzburg",
        postcode="89312",
        city="Günzburg",
    ),
    School(
        school="mwnuegy",
        name="Maria-Ward-Gymnasium Nürnberg",
        postcode="90489",
        city="Nürnberg",
    ),
    School(
        school="mwnuers",
        name="Maria-Ward-Realschule Nürnberg",
        postcode="90489",
        city="Nürnberg",
    ),
    School(
        school="mwrsn",
        name="Maria Ward Realschule Neuhaus",
        postcode="94152",
    ),
    School(
        school="nailagym",
        name="Hochfranken-Gymnasium Naila",
        postcode="95119",
        city="Naila",
    ),
    School(
        school="neugynue",
        name="Neues Gymnasium Nürnberg",
        postcode="90478",
        city="Nürnberg",
    ),
    School(
        school="neutragym",
        name="Gymnasium Neutraubling",
        postcode="93073",
        city="Neutraubling",
    ),
    School(
        school="nfgymuc",
        name="Gymnasium Neufreimann",
        postcode="80805",
        city="München",
    ),
    School(
        school="nkgwh",
        name="Nikolaus-Kopernikus-Gymnasium Weißenhorn",
        postcode="89264",
        city="Weißenhorn",
    ),
    School(
        school="nymph",
        name="Nymphenburger Schulen",
        postcode="80638",
        city="München",
    ),
    School(
        school="ohagym",
        name="Gymnasium Oberhaching",
        postcode="82041",
        city="Oberhaching",
    ),
    School(
        school="ohgyerl",
        name="Ohm-Gymnasium Erlangen",
        postcode="91052",
        city="Erlangen",
    ),
    School(
        school="olchigym",
        name="Gymnasium Olching",
        postcode="82140",
        city="Olching",
    ),
    School(
        school="omgyneu",
        name="Oskar-Maria-Graf-Gymnasium",
        postcode="85375",
    ),
    School(
        school="opgypul",
        name="Otfried-Preußler-Gymnasium Pullach",
        postcode="82049",
    ),
    School(
        school="ovmgymuc",
        name="Oskar-von-Miller-Gymnasium München",
        postcode="80803",
        city="München",
    ),
    School(
        school="ovtgym",
        name="Otto-von-Taube-Gymnasium Gauting",
        postcode="82131",
        city="Gauting",
    ),
    School(
        school="pafgym",
        name="Schyren-Gymnasium",
        postcode="85276",
        city="Pfaffenhofen an der Ilm",
    ),
    School(
        school="peugyau",
        name="Peutinger-Gymnasium Augsburg",
        postcode="86152",
        city="Augsburg",
    ),
    School(
        school="pfgyher",
        name="Paul-Pfinzing-Gymnasium",
        postcode="91217",
        city="Hersbruck",
    ),
    School(
        school="plagyans",
        name="Platen-Gymnasium Ansbach",
        postcode="91522",
        city="Ansbach",
    ),
    School(
        school="prmpul",
        name="Erzbischöfliches Pater-Rupert-Mayer-Gymnasium Pullach",
        postcode="82049",
    ),
    School(
        school="prmpulgs",
        name="Erzbischöfliche Pater-Rupert-Mayer-Grundschule Pullach",
        postcode="82049",
    ),
    School(
        school="psmsgraf",
        name="Propst-Seyberer-Mittelschule Grafenau",
    ),
    School(
        school="puheigy",
        name="Gymnasium Puchheim",
        postcode="82178",
        city="Puchheim",
    ),
    School(
        school="riegywue",
        name="Riemenschneider-Gymnasium Würzburg",
        postcode="97070",
        city="Würzburg",
    ),
    School(
        school="riwagybay",
        name="Richard-Wagner-Gymnasium Bayreuth",
        postcode="95444",
        city="Bayreuth",
    ),
    School(
        school="roewuegy",
        name="Röntgen-Gymnasium Würzburg",
        postcode="97070",
        city="Würzburg",
    ),
    School(
        school="rottlaugy",
        name="Rottmayr-Gymnasium Laufen",
        postcode="83410",
        city="Laufen",
    ),
    School(
        school="rsache",
        name="Achental-Realschule Marquartstein",
    ),
    School(
        school="rsgcham",
        name="Robert-Schuman-Gymnasium Cham",
    ),
    School(
        school="rsvat",
        name="Staatliche Realschule Vaterstetten",
        postcode="85598",
        city="Vaterstetten",
    ),
    School(
        school="rudigyau",
        name="Rudolf-Diesel-Gymnasium Augsburg",
        postcode="86163",
        city="Augsburg",
    ),
    School(
        school="rugymue",
        name="Ruperti-Gymnasium",
        postcode="84453",
        city="Mühldorf a. Inn",
    ),
    School(
        school="seligla",
        name="Gymnasium der Schulstiftung Seligenthal",
        postcode="84034",
        city="Landshut",
    ),
    School(
        school="seliglags",
        name="Grundschule der Schulstiftung Seligenthal",
        postcode="84034",
        city="Landshut",
    ),
    School(
        school="seligws",
        name="Wirtschaftsschule der Schulstiftung Seligenthal Landshut",
        postcode="84034",
        city="Landshut",
    ),
    School(
        school="shr",
        name="Samuel-Heinicke-Realschule",
        postcode="80992",
        city="München",
    ),
    School(
        school="siewuegym",
        name="Siebold-Gymnasium Würzburg",
        postcode="97070",
        city="Würzburg",
    ),
    School(
        school="simagygu",
        name="Simon-Marius-Gymnasium",
        postcode="91710",
        city="Gunzenhausen",
    ),
    School(
        school="sontgym",
        name="Gymnasium Sonthofen",
        postcode="87527",
        city="Sonthofen",
    ),
    School(
        school="sosgymuc",
        name="Städtisches Sophie-Scholl-Gymnasium München",
        postcode="80804",
        city="München",
    ),
    School(
        school="spmshau",
        name="Sport-Mittelschule Hauzenberg",
    ),
    School(
        school="stagymu",
        name="Staffelsee-Gymnasium Murnau",
        postcode="82418",
        city="Murnau am Staffelsee",
    ),
    School(
        school="stbgym",
        name="Gymnasium Starnberg",
        postcode="82319",
        city="Starnberg",
    ),
    School(
        school="stgogyna",
        name="St.-Gotthard-Gymnasium",
        postcode="94557",
    ),
    School(
        school="stugylen",
        name="Erzbischöfliches St.-Ursula-Gymnasium",
        postcode="50321",
        city="Brühl",
    ),
    School(
        school="tassimgy",
        name="Tassilo-Gymnasium Simbach am Inn",
        postcode="84359",
        city="Simbach",
    ),
    School(
        school="tgamuc",
        name="Theresia-Gerhardinger-Gymnasium am Anger",
        postcode="80331",
        city="München",
    ),
    School(
        school="tgrs",
        name="Erzbischöfliche Theresia-Gerhardinger-Mädchenrealschule",
        postcode="81541",
        city="München",
    ),
    School(
        school="theheugym",
        name="Theodor-Heuss-Gymnasium Nördlingen",
        postcode="86720",
        city="Nördlingen",
    ),
    School(
        school="theogymuc",
        name="Städtisches Theodolinden-Gymnasium München",
        postcode="81547",
        city="München",
    ),
    School(
        school="thergymuc",
        name="Theresien-Gymnasium München",
        postcode="80336",
        city="München",
    ),
    School(
        school="thomagymuc",
        name="Städtisches Thomas-Mann-Gymnasium München",
        postcode="81379",
        city="München",
    ),
    School(
        school="toelgvs",
        name="Gabriel-von-Seidl-Gymnasium Bad Tölz",
        postcode="83646",
        city="Bad Tölz",
    ),
    School(
        school="trugymuc",
        name="Gymnasium Trudering",
        postcode="81827",
        city="München",
    ),
    School(
        school="ufggym",
        name="Gymnasium Unterföhring",
        postcode="85774",
        city="Unterföhring",
    ),
    School(
        school="ugriegym",
        name="Gymnasium Untergriesbach",
        postcode="94107",
    ),
    School(
        school="urstragym",
        name="Gymnasium der Ursulinen-Schulstiftung Straubing",
        postcode="94315",
        city="Straubing",
    ),
    School(
        school="veihoegym",
        name="Gymnasium Veitshöchheim",
        postcode="97209",
    ),
    School(
        school="vhgybo",
        name="Veit-Höser-Gymnasium Bogen",
        postcode="94327",
        city="Bogen",
    ),
    School(
        school="visgyffb",
        name="Viscardi-Gymnasium Fürstenfeldbruck",
        postcode="82256",
        city="Fürstenfeldbruck",
    ),
    School(
        school="wbgl",
        name="Wolfgang-Borchert-Gymnasium Langenzenn",
        postcode="90579",
        city="Langenzenn",
    ),
    School(
        school="weilgym",
        name="Gymnasium Weilheim i. OB",
        postcode="82362",
        city="Weilheim in Oberbayern",
    ),
    School(
        school="welfen",
        name="Welfen-Gymnasium Schongau",
        postcode="86956",
        city="Schongau",
    ),
    School(
        school="wggselb",
        name="Walter-Gropius-Gymnasium Selb",
        postcode="95100",
        city="Selb",
    ),
    School(
        school="wggymuc",
        name="Städtisches Willi-Graf-Gymnasium München",
        postcode="80804",
        city="München",
    ),
    School(
        school="whgga",
        name="Werner-Heisenberg-Gymnasium Garching",
        postcode="85748",
        city="Garching bei München",
    ),
    School(
        school="whgmuc",
        name="Wilhelm-Hausenstein-Gymnasium München",
        postcode="81925",
        city="München",
    ),
    School(
        school="widipogy",
        name="Wilhelm-Diess-Gymnasium Pocking",
        postcode="94060",
        city="Pocking",
    ),
    School(
        school="wigywue",
        name="Wirsberg-Gymnasium Würzburg",
        postcode="97070",
        city="Würzburg",
    ),
    School(
        school="willigym",
        name="Willibald-Gluck-Gymnasium",
        postcode="92318",
        city="Neumarkt in der Oberpfalz",
    ),
    School(
        school="witgymuc",
        name="Wittelsbacher-Gymnasium München",
        postcode="80335",
        city="München",
    ),
    School(
        school="wkrstauf",
        name="Walter-Klingenbeck-Schule Taufkirchen",
        postcode="82024",
        city="Taufkirchen",
    ),
    School(
        school="wmrstrau",
        name="Walter-Mohr-Realschule Traunreut",
        postcode="83301",
        city="Traunreut",
    ),
    School(
        school="wvsgsau",
        name="Werner-von-Siemens-Grundschule Augsburg",
        postcode="86163",
        city="Augsburg",
    ),
    School(
        school="wvsgymuc",
        name="Städtisches Werner-von-Siemens-Gymnasium München",
        postcode="81735",
        city="München",
    ),
    School(
        school="wwgybay",
        name="Wirtschaftswissenschaftliches und Naturwissenschaftlich-technologisches Gymnasium der Stadt Bayreuth",
        postcode="95448",
        city="Bayreuth",
    ),
]
